# -*- coding: utf-8 -*-

# Informations utilisée par l'installeur sous Windows.
# titre : description sommaire du module
# description : description détaillée
# defaut : par défaut, le module est-il installé ou non ?

description = {
"titre":                    "Traceur de surfaces",
"description":              "Traceur de surfaces (encore rudimentaire).",
"groupe":                   "Modules",
"defaut":  True,
}